# ECE 205: Advanced Calculus 1

## Laplace transform

The Laplace transform is a wonderful operation to convert a function of $t$ into a function of $s$. Where $s$ is an unknown variable independent of $t$:

$$
\mathcal L\{f(t)\}=F(s)=\int^\infty_0e^{-st}f(t)dt, s > 0
$$

??? example
    To solve for $\mathcal L\{\sin(at)\}$:

    \begin{align*}
    \mathcal L\{f(t)\}&=\int^\infty_0e^{-st}\sin(at)dt \\
    \\
    \text{IBP: let $u=\sin(at)$, $dv=e^{-st}dt$:} \\
    &=\lim_{B\to\infty} \underbrace{\biggr[
    	\cancel{-\frac 1 se^{-st}\sin(at)}}_\text{0 when $s=0$ or $s=\infty$}+\frac a s\int e^{-st}\cos(at)dt
    \biggr]^B_0 \\
    &=\frac a s\lim_{B\to\infty}\left[\int e^{-st}\cos(at)dt \right]^B_0 \\
    \text{IBP: let $u=\cos(at)$, $dv=e^{-st}dt$:} \\
    &=\frac a s \lim_{B\to\infty}\left[
    	-\frac 1 s e^{-st}\cos(at)-\frac a s\underbrace{\int e^{-st}\sin(at)dt}_{\mathcal L\{\sin(at)\}}
    \right]^B_0 \\
    &=\frac{a}{s^2}-\frac{a^2}{s^2}\mathcal L\{\sin(at)\} \\
    \mathcal L\{\sin(at)\}\left(1+\frac{a^2}{s^2}\right)&=\frac{a}{s^2} \\
    \mathcal L\{\sin(at)\}&=\frac{a}{a^2+s^2}, s > 0
    \end{align*}

A **piecewise continuous** function on $[a,b]$ is continuous on $[a,b]$ except for a possible finite number of finite jump discontinuities.

- This means that any jump discontinuities must have a finite limit on both sides.
- A piecewise continuous function on $[0,\infty)$ must be piecewise continuous $\forall B>0, [0,B]$.
   
The **exponential order** of a function is $a$ if there exist constants $K, M$ such that:
$$|f(t)|\leq Ke^{at}\text{ when } t\geq M$$

!!! example
    - $f(t)=7e^t\sin t$ has an exponential order of 1.
    - $f(t)=e^{t^2}$ does not have an exponential order.

### Linearity

A **piecewise continuous** function $f$ on $[0,\infty)$ of an exponential order $a$ has a defined Laplace transform for $s>a$.

Laplace transforms are **linear**. If there exist LTs for $f_1, f_2$ for $s>a_1, a_2$, respectively, for $s=\text{max}(a_1, a_2)$:

$$\mathcal L\{c_1f_1 + c_2f_2\} = c_1\mathcal L\{f_1\} + c_2\mathcal L\{f_2\}$$

??? example
    We find the Laplace transform for the following.
    
    $$
    f(t)=\begin{cases}
    1 & 0\leq t < 1 \\
    e^{-t} & t\geq 1
    \end{cases}
    $$
    
    Clearly $f(t)$ is piecewise ocontinuous on $[0,\infty)$ and has an exponential order of -1 when $t\geq 1$ and 0 when $0\leq t<1$. Thus $\mathcal L\{f(t)\}$ is defined for $s>0$.
    
    \begin{align*}
    \mathcal L\{f(t)\}&=\int^1_0 e^{-st}dt + \int^\infty_1e^{-st}e^{-t}dt \\
    \tag{$s\neq 0$}&=\left[-\frac 1 s e^{-st}\right]^1_0 + \int^\infty_1e^{t(-s-1)}dt \\
    &=-\frac 1 se^{-s}+\frac 1 s + \lim_{B\to\infty}\left[ \frac{1}{-s-1}e^{t(-s-1)} \right]^B_1 \\
    \tag{$s\neq 0,s>-1$}&=\frac{-e^{-s}+1}{s} -\frac{e^{-s-1}}{-s-1}
    \end{align*}
    
    We solve for the special case $s=0$:
    \begin{align*}
    \mathcal L\{f(t)\}&=\int^1_0 e^{0}dt + \int^\infty_1e^{-st}e^{-t}dt \\
    &=1 -\frac{e^{-s-1}}{-s-1} \\
    \end{align*}
    
    $$
    \mathcal L\{f(t)\}=
    \begin{cases}
    \frac{-e^{-s}+1}{s}-\frac{e^{-s-1}}{-s-1} & s\neq 0, s>-1 \\
    1-\frac{e^{-s-1}}{-s-1} &s=0
    \end{cases}
    $$

If there exists a transform for $s>a$, the original function multiplied by $e^{-bt}$ exists for $s>a+b$.

$$\mathcal L\{f(t)\}=F(s), s>a\implies \mathcal L\{e^{-bt}f(t)\}=F(s),s>a+b$$

### Inverse transform

The inverse is found by manipulating the equation until you can look it up in the [Laplace Table](#resources).

The inverse transform is also **linear**.

### Inverse of rational polynomials

If the transformed function can be expressed as a partial fraction decomposition, it is often easier to use linearity to reference the table.

$$\mathcal L^{-1}\left\{\frac{P(s)}{Q(s)}\right\}$$

- $Q, P$ are polynomials
- $\text{deg}(P) > \text{deg}(Q)$
- $Q$ is factored

??? example
    \begin{align*}
    \mathcal L^{-1}\left\{\frac{s^2+9s+2}{(s-1)(s^2+2s-3)}\right\} &=\mathcal L^{-1}\left\{\frac{A}{s-1}+\frac{B}{s+3} + \frac{Cs+D}{(s-1)^2}\right\} \\
    &\implies A=2,B=3,C=-1 \\
    &=2\mathcal L^{-1}\left\{\frac{1}{s-1}\right\} + 3\mathcal L^{-1}\left\{\frac{1}{(s-1)^2}\right\}-\mathcal L^{-1}\left\{\frac{1}{s+3}\right\} \\
    &=2e^t+3te^t-e^{-3t}
    \end{align*}

### Inverse of differentiable equations

If a function $f$ is continuous on $[0,\infty)$ and its derivative $f'$ is piecewise continuous on $[0,\infty)$, for $s>a$:

$$
\mathcal L\{ f'\}=s\mathcal L\{f\}-f(0) \\
\mathcal L\{ f''\} = s^2\mathcal L\{f\}-s\cdot f(0)-f'(0)
$$

### Solving IVPs

Applying the Laplace transform to both sides of an IVP is valid to remove any traces of horrifying integration.

!!! example
    \begin{align*}
    y''-y'-2y=0, y(0)=1, y'(0)=0 \\
    \mathcal L\{y''-y'-2y\}&=\mathcal L\{0\} \\
    s^2\mathcal L\{y\}-s\cdot y(0)-y'(0) - s\mathcal L\{y\} +y(0) - 2\mathcal L\{y\}&=0 \\
    \mathcal L\{y\}(s^2-s-2)-s+1&=0 \\
    \mathcal L\{y\}&=\frac{s-1}{(s-2)(s+1)} \\
    &= \\
    \mathcal L^{-1}\{\mathcal L\{y\}\}&=\mathcal L^{-1}\left\{
   	 \frac 1 3\cdot\frac{1}{s-2} + \frac 2 3\cdot\frac{1}{s+1}
    \right\} \\
    y&=\frac 1 3\mathcal L^{-1}\left\{\frac{1}{s-2}\right\} + \frac 2 3\mathcal L^{-1}\left\{\frac{1}{s+1}\right\} \\
    \tag{from Laplace table}&=\frac 1 3 e^{2t} + \frac 2 3 e^{-t}
    \end{align*}

### Heaviside / unit step

The Heaviside and unit step functions are identical:

$$
H(t-c)=u(t-c)=u_c(t)=\begin{cases}
0 & t < c \\
1 & t \geq c
\end{cases}
$$

Piecewise continuous functions can be manipulated into a single equation via the Heaviside function.

For a Heaviside transform $\mathcal L\{u_c(t)g(t)\}$, if $g$ is defined on $[0,\infty)$, $c\geq 0$, and $\mathcal L\{g(t+c)\}$ exists for some $s>s_0$:

$$
\mathcal L\{u_c(t)g(t)\}=e^{-sc}\mathcal L\{g(t+c)\},s>s_0
$$

Likewise, under the same conditions, shifting it twice restores it back to the original.

$$
\mathcal L\{u_c(t)f(t-c)\}=e^{-sc}\mathcal L\{f\}
$$


## Resources

- [Laplace Table](/resources/ece/laplace.pdf)
